@@ -1,5 +1,6 @@
-# Copyright 2021 UW-IT, University of Washington
+# Copyright 2022 UW-IT, University of Washington
 # SPDX-License-Identifier: Apache-2.0
+
 import json
 from restclients_core import models
 from dateutil.parser import parse
@@ -42,6 +43,7 @@ class Subscription(models.Model):
     SUBS_CODE_CANVAS_STUDENT = 77
     SUBS_CODE_CANVAS_AFFILIATE = 78
     SUBS_CODE_CANVAS_SPONSORED = 79
+    SUBS_CODE_HUSKY_ONNET_EXTENSION = 89
     SUBS_CODE_U_FORWARDING = 105
     SUBS_CODE_GOOGLE_APPS = 144
     SUBS_CODE_GOOGLE_APPS_TEST = 145
@@ -169,14 +171,19 @@ class SubscriptionPostResponse(models.Model):
     http_status = models.SmallIntegerField()
     more_info = models.CharField(max_length=512)
 
-    def from_json(self, uwnetid, data):
-        self.uwnetid = uwnetid
-        self.time_stamp = data['timeStamp']
-        self.action = data['action']
-        self.result = data['result']
-        self.http_status = int(data['httpStatus'])
-        self.more_info = data['moreInfo']
-        self.query = data['query']
+    def from_json(self, data):
+        try:
+            self.uwnetid = data['query']['action']
+            self.time_stamp = data['timeStamp']
+            self.action = data['query']['action']
+            self.result = data['result']
+            self.http_status = int(data['httpStatus'])
+            self.more_info = data['moreInfo']
+            self.query = data['query']
+        except KeyError:
+            raise Exception(
+                "Malformed Sub POST Response: {}".format(data))
+
         return self
 
 
@@ -321,6 +328,7 @@ class Category(models.Model):
     CANVAS_PROVISIONEE = 236
     ZOOM_LICENSED_PROVISIONEE = 237
     ZOOM_BASIC_PROVISIONEE = 238
+    HUSKY_ONNET_EXT_PROVISIONEE = 239
 
     STATUS_ACTIVE = 1
     STATUS_GRACE = 2
